@@ -305,10 +305,14 @@ ucase_ext[i] = 0;
 #define CHDIR_GETOPT
 #endif
 
-#ifdef WAVE_HAVE_GCONF
+#if defined(WAVE_HAVE_GCONF) || defined(WAVE_HAVE_GSETTINGS)
 #define RPC_GETOPT  "  -1, --rpcid=RPCID          specify RPCID of GConf session\n"
+#if defined(WAVE_HAVE_GCONF)
 #define RPC_GETOPT3 "  -3, --restore              restore previous RPCID numbered session\n"
 #else
+#define RPC_GETOPT3 "  -3, --restore              restore previous session\n"
+#endif
+#else
 #define RPC_GETOPT
 #define RPC_GETOPT3
 #endif
@@ -344,6 +348,7 @@ RPC_GETOPT
 CHDIR_GETOPT
 RPC_GETOPT3
 "  -4, --rcvar                specify single rc variable values individually\n"
+"  -5, --sstexclude           specify sst exclusion filter filename\n"
 INTR_GETOPT
 "  -C, --comphier             use compressed hierarchy names (slower)\n"
 "  -g, --giga                 use gigabyte mempacking when recoding (slower)\n"
@@ -697,6 +702,8 @@ if(!GLOBALS)
 	GLOBALS->do_hier_compress = old_g->do_hier_compress;
 	GLOBALS->disable_auto_comphier = old_g->disable_auto_comphier;
 
+	strcpy2_into_new_context(GLOBALS, &GLOBALS->sst_exclude_filename, &old_g->sst_exclude_filename);
+
 	strcpy2_into_new_context(GLOBALS, &GLOBALS->editor_name, &old_g->editor_name);
 	strcpy2_into_new_context(GLOBALS, &GLOBALS->fontname_logfile, &old_g->fontname_logfile);
 	strcpy2_into_new_context(GLOBALS, &GLOBALS->fontname_signals, &old_g->fontname_signals);
@@ -817,10 +824,11 @@ while (1)
 		{"chdir", 1, 0, '2'},
 		{"restore", 0, 0, '3'},
                 {"rcvar", 1, 0, '4'},
+		{"sstexclude", 1, 0, '5'},
                 {0, 0, 0, 0}
                 };
 
-        c = getopt_long (argc, argv, "zf:Fon:a:Ar:dl:s:e:c:t:NS:vVhxX:MD:IgCLR:P:O:WT:1:2:34:", long_options,
+        c = getopt_long (argc, argv, "zf:Fon:a:Ar:dl:s:e:c:t:NS:vVhxX:MD:IgCLR:P:O:WT:1:2:34:5:", long_options,
 &option_index);
 
         if (c == -1) break;     /* no more args */
@@ -958,7 +966,7 @@ while (1)
 			break;
 
 		case '3':
-#ifdef WAVE_HAVE_GCONF
+#if defined(WAVE_HAVE_GCONF) || defined(WAVE_HAVE_GSETTINGS)
 			{
 			is_vcd = 0;
 			wave_gconf_restore(&GLOBALS->loaded_file_name, &wname, &override_rc, &chdir_cache, &opt_vcd);
@@ -1034,6 +1042,16 @@ while (1)
 			}
 			break;
 
+                case '5':
+                        {
+                        if(GLOBALS->sst_exclude_filename)
+                                {
+                                free_2(GLOBALS->sst_exclude_filename);
+                                }
+                        GLOBALS->sst_exclude_filename = strdup_2(optarg);
+                        }
+                        break;
+
                 case 's':
 			if(GLOBALS->skip_start) free_2(GLOBALS->skip_start);
 			GLOBALS->skip_start = malloc_2(strlen(optarg)+1);
@@ -1391,6 +1409,7 @@ if(is_vcd)
 	}
 
 strcat(GLOBALS->winname,GLOBALS->loaded_file_name);
+sst_exclusion_loader();
 
 loader_check_head:
 
@@ -2523,7 +2542,7 @@ if(scriptfile
 	scriptfile=NULL;
 	}
 
-#ifdef WAVE_HAVE_GCONF
+#if defined(WAVE_HAVE_GCONF) || defined(WAVE_HAVE_GSETTINGS)
 if(GLOBALS->loaded_file_type != MISSING_FILE)
 	{
 	if(!chdir_cache) { wave_gconf_client_set_string("/current/pwd", getenv("PWD")); }
